from .... pyaz_utils import call_az

def show(account, storage_account_name, resource_group=None):
    return call_az("az dla account blob-storage show", locals())


def add(access_key, account, storage_account_name, resource_group=None, suffix=None):
    '''
    Links an Azure Storage account to the specified Data Lake Analytics account.
    '''
    return call_az("az dla account blob-storage add", locals())


def update(access_key, account, storage_account_name, resource_group=None, suffix=None):
    '''
    Updates an Azure Storage account linked to the specified Data Lake Analytics account.
    '''
    return call_az("az dla account blob-storage update", locals())


def delete(account, storage_account_name, resource_group=None):
    return call_az("az dla account blob-storage delete", locals())


def list(account, count=None, filter=None, orderby=None, resource_group=None, select=None, skip=None, top=None):
    return call_az("az dla account blob-storage list", locals())




from ..... pyaz_utils import call_az

def set(name, resource_group, status, transparent_data_encryption_name, workspace_name):
    '''
    Set a SQL pool's transparent data encryption configuration.
    '''
    return call_az("az synapse sql pool tde set", locals())


def show(name, resource_group, transparent_data_encryption_name, workspace_name):
    '''
    Get a SQL pool's transparent data encryption configuration.
    '''
    return call_az("az synapse sql pool tde show", locals())




from .... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Get the details of a dedicated host group.
    '''
    return call_az("az vm host group show", locals())


def get_instance_view(name, resource_group):
    '''
    Get instance view of a dedicated host group.
    '''
    return call_az("az vm host group get-instance-view", locals())


def create(name, platform_fault_domain_count, resource_group, automatic_placement=None, location=None, tags=None, zone=None):
    '''
    Create a dedicated host group.
    '''
    return call_az("az vm host group create", locals())


def list(resource_group=None):
    '''
    List dedicated host groups.
    '''
    return call_az("az vm host group list", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a dedicated host group.
    '''
    return call_az("az vm host group update", locals())


def delete(name, resource_group, yes=None):
    return call_az("az vm host group delete", locals())




from ... pyaz_utils import call_az
from . import authorization_rule


def set(alias, namespace_name, partner_namespace, resource_group, alternate_name=None):
    '''
    Sets Service Bus Geo-Disaster Recovery Configuration Alias for the give Namespace
    '''
    return call_az("az servicebus georecovery-alias set", locals())


def show(alias, namespace_name, resource_group):
    '''
    shows properties of Service Bus Geo-Disaster Recovery Configuration Alias for Primay/Secondary Namespace
    '''
    return call_az("az servicebus georecovery-alias show", locals())


def list(namespace_name, resource_group):
    return call_az("az servicebus georecovery-alias list", locals())


def break_pair(alias, namespace_name, resource_group):
    '''
    Disables Service Bus Geo-Disaster Recovery Configuration Alias and stops replicating changes from primary to secondary namespaces
    '''
    return call_az("az servicebus georecovery-alias break-pair", locals())


def fail_over(alias, namespace_name, resource_group, parameters=None):
    '''
    Invokes Service Bus Geo-Disaster Recovery Configuration Alias failover and re-configure the alias to point to the secondary namespace
    '''
    return call_az("az servicebus georecovery-alias fail-over", locals())


def exists(alias, namespace_name, resource_group):
    '''
    Check if Geo Recovery Alias Name is available
    '''
    return call_az("az servicebus georecovery-alias exists", locals())


def delete(alias, namespace_name, resource_group):
    '''
    Deletes Service Bus Geo-Disaster Recovery Configuration Alias request accepted
    '''
    return call_az("az servicebus georecovery-alias delete", locals())




from ... pyaz_utils import call_az
from . import profile, rule


def create(count, resource, action=None, disabled=None, email_administrator=None, email_coadministrators=None, location=None, max_count=None, min_count=None, name=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, tags=None):
    '''
    Create new autoscale settings.
    '''
    return call_az("az monitor autoscale create", locals())


def update(name, resource_group, add=None, add_action=None, count=None, email_administrator=None, email_coadministrators=None, enabled=None, force_string=None, max_count=None, min_count=None, remove=None, remove_action=None, set=None, tags=None):
    '''
    Update autoscale settings.
    '''
    return call_az("az monitor autoscale update", locals())


def delete(name, resource_group):
    return call_az("az monitor autoscale delete", locals())


def show(name, resource_group):
    '''
    Show autoscale setting details.
    '''
    return call_az("az monitor autoscale show", locals())


def list(resource_group):
    return call_az("az monitor autoscale list", locals())




from .... pyaz_utils import call_az

def show(analytics_query, name, resource_group, timespan=None):
    '''
    Execute a query against the Log Analytics workspace linked with a VM.
    '''
    return call_az("az vm monitor log show", locals())




from ... pyaz_utils import call_az

def show(endpoint_name, name, profile_name, resource_group):
    '''
    Show details for the custom domain of a CDN.
    '''
    return call_az("az cdn custom-domain show", locals())


def delete(endpoint_name, name, profile_name, resource_group):
    '''
    Delete the custom domain of a CDN.
    '''
    return call_az("az cdn custom-domain delete", locals())


def list(endpoint_name, profile_name, resource_group):
    return call_az("az cdn custom-domain list", locals())


def create(endpoint_name, hostname, name, profile_name, resource_group, location=None, tags=None):
    '''
    Create a new custom domain to provide a hostname for a CDN endpoint.
    '''
    return call_az("az cdn custom-domain create", locals())


def enable_https(endpoint_name, name, profile_name, resource_group, min_tls_version=None, user_cert_group_name=None, user_cert_protocol_type=None, user_cert_secret_name=None, user_cert_secret_version=None, user_cert_subscription_id=None, user_cert_vault_name=None):
    '''
    Enable HTTPS for a custom domain. The resource name of the custom domain could be obtained using "az cdn custom-domain list".
    '''
    return call_az("az cdn custom-domain enable-https", locals())


def disable_https(endpoint_name, name, profile_name, resource_group):
    return call_az("az cdn custom-domain disable-https", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List probes.
    '''
    return call_az("az network application-gateway probe list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a probe.
    '''
    return call_az("az network application-gateway probe show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a probe.
    '''
    return call_az("az network application-gateway probe delete", locals())


def create(gateway_name, name, path, protocol, resource_group, host=None, host_name_from_http_settings=None, interval=None, match_body=None, match_status_codes=None, min_servers=None, no_wait=None, port=None, threshold=None, timeout=None):
    '''
    Create a probe.
    '''
    return call_az("az network application-gateway probe create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, host=None, host_name_from_http_settings=None, interval=None, match_body=None, match_status_codes=None, min_servers=None, no_wait=None, path=None, port=None, protocol=None, remove=None, set=None, threshold=None, timeout=None):
    '''
    Update a probe.
    '''
    return call_az("az network application-gateway probe update", locals())




from .... pyaz_utils import call_az

def add(cluster_name, extension_name, extension_type, publisher, resource_group, type_handler_version, auto_upgrade_minor_version=None, force_update_tag=None, protected_setting=None, provision_after_extension=None, setting=None):
    '''
    Add an extension to the node type.
    '''
    return call_az("az sf managed-node-type vm-extension add", locals())


def delete(cluster_name, extension_name, resource_group):
    '''
    Delete an extension to the node type.
    '''
    return call_az("az sf managed-node-type vm-extension delete", locals())




from ... pyaz_utils import call_az

def list(reservation_order_id):
    '''
    Get all reservations.
    '''
    return call_az("az reservations reservation list", locals())


def show(reservation_id, reservation_order_id, expand=None):
    '''
    Get details of a reservation.
    '''
    return call_az("az reservations reservation show", locals())


def list_history(reservation_id, reservation_order_id):
    '''
    Get history of a reservation.
    '''
    return call_az("az reservations reservation list-history", locals())


def update(applied_scope_type, reservation_id, reservation_order_id, applied_scopes=None, instance_flexibility=None):
    '''
    Updates the applied scopes of the reservation.
    '''
    return call_az("az reservations reservation update", locals())


def split(quantity_1, quantity_2, reservation_id, reservation_order_id):
    '''
    Split a reservation.
    '''
    return call_az("az reservations reservation split", locals())


def merge(reservation_id_1, reservation_id_2, reservation_order_id):
    '''
    Merge two reservations.
    '''
    return call_az("az reservations reservation merge", locals())




from ... pyaz_utils import call_az

def create(name, advanced_filter=None, azure_active_directory_application_id_or_uri=None, azure_active_directory_tenant_id=None, deadletter_endpoint=None, deadletter_identity=None, deadletter_identity_endpoint=None, delivery_attribute_mapping=None, delivery_identity=None, delivery_identity_endpoint=None, delivery_identity_endpoint_type=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, event_delivery_schema=None, event_ttl=None, expiration_date=None, included_event_types=None, labels=None, max_delivery_attempts=None, max_events_per_batch=None, preferred_batch_size_in_kilobytes=None, source_resource_id=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_case_sensitive=None, subject_ends_with=None):
    '''
    Create a new event subscription.
    '''
    return call_az("az eventgrid event-subscription create", locals())


def show(name, include_full_endpoint_url=None, include_static_delivery_attribute_secret=None, source_resource_id=None):
    '''
    Get the details of an event subscription.
    '''
    return call_az("az eventgrid event-subscription show", locals())


def delete(name, source_resource_id=None):
    '''
    Delete an event subscription.
    '''
    return call_az("az eventgrid event-subscription delete", locals())


def list(location=None, odata_query=None, resource_group=None, source_resource_id=None, topic_type_name=None):
    '''
    List event subscriptions.
    '''
    return call_az("az eventgrid event-subscription list", locals())


def update(name, add=None, advanced_filter=None, deadletter_endpoint=None, deadletter_identity=None, deadletter_identity_endpoint=None, delivery_attribute_mapping=None, delivery_identity=None, delivery_identity_endpoint=None, delivery_identity_endpoint_type=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, force_string=None, included_event_types=None, labels=None, remove=None, set=None, source_resource_id=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_ends_with=None):
    '''
    Update an event subscription.
    '''
    return call_az("az eventgrid event-subscription update", locals())




from .... pyaz_utils import call_az

def create(auto_renew, commitment_plan_name, hosting_model, name, plan_type, resource_group, current_count=None, current_tier=None, next_count=None, next_tier=None):
    '''
    Create a commitment plan for Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account commitment-plan create", locals())


def delete(commitment_plan_name, name, resource_group):
    '''
    Delete a commitment plan from Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account commitment-plan delete", locals())


def show(commitment_plan_name, name, resource_group):
    '''
    Show a commitment plan from Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account commitment-plan show", locals())


def list(name, resource_group):
    '''
    Show all commitment plans from Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account commitment-plan list", locals())




from ... pyaz_utils import call_az

def show(name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Retrieve the specified protectable item within the given container.
    '''
    return call_az("az backup protectable-item show", locals())


def list(resource_group, vault_name, workload_type, backup_management_type=None, container_name=None, protectable_item_type=None, server_name=None):
    '''
    Retrieve all protectable items within a certain container or across all registered containers.
    '''
    return call_az("az backup protectable-item list", locals())


def initialize(container_name, resource_group, vault_name, workload_type):
    '''
    Trigger the discovery of any unprotected items of the given workload type in the given container.
    '''
    return call_az("az backup protectable-item initialize", locals())




from .. pyaz_utils import call_az
from . import firewall_rules, patch_schedule, server_link


def create(location, name, resource_group, sku, vm_size, enable_non_ssl_port=None, minimum_tls_version=None, redis_configuration=None, redis_version=None, replicas_per_master=None, shard_count=None, static_ip=None, subnet_id=None, tags=None, tenant_settings=None, zones=None):
    '''
    Create new Redis Cache instance.
    '''
    return call_az("az redis create", locals())


def delete(name, resource_group, yes=None):
    return call_az("az redis delete", locals())


def export(container, name, prefix, resource_group, file_format=None):
    '''
    Export data stored in a Redis cache.
    '''
    return call_az("az redis export", locals())


def force_reboot(name, reboot_type, resource_group, shard_id=None):
    '''
    Reboot specified Redis node(s).
    '''
    return call_az("az redis force-reboot", locals())


def import_method(files, name, resource_group, file_format=None):
    '''
    Import data into Redis cache.
    '''
    return call_az("az redis import-method", locals())


def import_(files, name, resource_group, file_format=None):
    '''
    Import data into a Redis cache.
    '''
    return call_az("az redis import", locals())


def list(resource_group=None):
    '''
    List Redis Caches.
    '''
    return call_az("az redis list", locals())


def list_keys(name, resource_group):
    return call_az("az redis list-keys", locals())


def regenerate_keys(key_type, name, resource_group):
    '''
    Regenerate Redis cache's access keys.
    '''
    return call_az("az redis regenerate-keys", locals())


def show(name, resource_group):
    return call_az("az redis show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, sku=None, vm_size=None):
    '''
    Update a Redis cache.
    '''
    return call_az("az redis update", locals())




from .. pyaz_utils import call_az
from . import project


def check_name(location, name):
    '''
    Check if a given DMS instance name is available in a given region as well as the name's validity.
    '''
    return call_az("az dms check-name", locals())


def check_status(name, resource_group):
    '''
    Perform a health check and return the status of the service and virtual machine size.
    '''
    return call_az("az dms check-status", locals())


def create(location, name, resource_group, sku_name, subnet, no_wait=None, tags=None):
    '''
    Create an instance of the Data Migration Service.
    '''
    return call_az("az dms create", locals())


def delete(name, resource_group, delete_running_tasks=None, no_wait=None, yes=None):
    '''
    Delete an instance of the Data Migration Service.
    '''
    return call_az("az dms delete", locals())


def list(resource_group=None):
    '''
    List the DMS instances within your currently configured subscription (to set this use "az account set"). If provided, only show the instances within a given resource group.
    '''
    return call_az("az dms list", locals())


def show(name, resource_group):
    '''
    Show the details for an instance of the Data Migration Service.
    '''
    return call_az("az dms show", locals())


def start(name, resource_group, no_wait=None):
    '''
    Start an instance of the Data Migration Service. It can then be used to run data migrations.
    '''
    return call_az("az dms start", locals())


def stop(name, resource_group, no_wait=None):
    '''
    Stop an instance of the Data Migration Service. While stopped, it can't be used to run data migrations and the owner won't be billed.
    '''
    return call_az("az dms stop", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the DMS instance is met.
    '''
    return call_az("az dms wait", locals())


def list_skus():
    '''
    List the SKUs that are supported by the Data Migration Service.
    '''
    return call_az("az dms list-skus", locals())




from ... pyaz_utils import call_az
from . import version


def list(cluster_name, resource_group):
    '''
    List managed application types of a given managed cluster.
    '''
    return call_az("az sf managed-application-type list", locals())


def delete(cluster_name, name, resource_group):
    '''
    Delete a managed application type.
    '''
    return call_az("az sf managed-application-type delete", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the properties of a managed application type on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-application-type show", locals())


def create(cluster_name, name, resource_group, tags=None):
    '''
    Create a new managed application type on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-application-type create", locals())


def update(cluster_name, name, resource_group, tags=None):
    '''
    Update an managed application type.
    '''
    return call_az("az sf managed-application-type update", locals())




from .... pyaz_utils import call_az

def list(managed_instance, resource_group):
    return call_az("az sql mi op list", locals())


def show(managed_instance, name, resource_group):
    return call_az("az sql mi op show", locals())


def cancel(managed_instance, name, resource_group):
    return call_az("az sql mi op cancel", locals())




from ... pyaz_utils import call_az

def list(filter=None):
    '''
    List deployments at subscription scope.
    '''
    return call_az("az deployment sub list", locals())


def show(name):
    '''
    Show a deployment at subscription scope.
    '''
    return call_az("az deployment sub show", locals())


def delete(name, no_wait=None):
    '''
    Delete a deployment at subscription scope.
    '''
    return call_az("az deployment sub delete", locals())


def validate(location, handle_extended_json_format=None, name=None, no_prompt=None, parameters=None, query_string=None, template_file=None, template_spec=None, template_uri=None):
    '''
    Validate whether a template is valid at subscription scope.
    '''
    return call_az("az deployment sub validate", locals())


def create(location, confirm_with_what_if=None, handle_extended_json_format=None, name=None, no_prompt=None, no_wait=None, parameters=None, proceed_if_no_change=None, query_string=None, template_file=None, template_spec=None, template_uri=None, what_if=None, what_if_exclude_change_types=None, what_if_result_format=None):
    '''
    Start a deployment at subscription scope.
    '''
    return call_az("az deployment sub create", locals())


def what_if(location, exclude_change_types=None, name=None, no_pretty_print=None, no_prompt=None, parameters=None, query_string=None, result_format=None, template_file=None, template_spec=None, template_uri=None):
    '''
    Execute a deployment What-If operation at subscription scope.
    '''
    return call_az("az deployment sub what-if", locals())


def export(name):
    '''
    Export the template used for a deployment.
    '''
    return call_az("az deployment sub export", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a deployment condition is met.
    '''
    return call_az("az deployment sub wait", locals())


def cancel(name):
    '''
    Cancel a deployment at subscription scope.
    '''
    return call_az("az deployment sub cancel", locals())




from .... pyaz_utils import call_az

def reimage(cluster_name, node_name, resource_group, force=None):
    '''
    Reimage nodes of a node type.
    '''
    return call_az("az sf managed-node-type node reimage", locals())


def restart(cluster_name, node_name, resource_group, force=None):
    '''
    Restart nodes of a node type.
    '''
    return call_az("az sf managed-node-type node restart", locals())


def delete(cluster_name, node_name, resource_group, force=None):
    '''
    Delete nodes of a node type.
    '''
    return call_az("az sf managed-node-type node delete", locals())




from ... pyaz_utils import call_az
from . import op


def create(name, resource_group, server, capacity=None, db_dtu_max=None, db_dtu_min=None, family=None, license_type=None, maint_config_id=None, max_size=None, no_wait=None, tags=None, tier=None, zone_redundant=None):
    '''
    Create an elastic pool.
    '''
    return call_az("az sql elastic-pool create", locals())


def delete(name, resource_group, server, no_wait=None):
    return call_az("az sql elastic-pool delete", locals())


def show(name, resource_group, server):
    return call_az("az sql elastic-pool show", locals())


def list(resource_group, server, skip=None):
    return call_az("az sql elastic-pool list", locals())


def update(name, resource_group, server, add=None, capacity=None, db_dtu_max=None, db_dtu_min=None, family=None, force_string=None, maint_config_id=None, max_size=None, no_wait=None, remove=None, set=None, tier=None, zone_redundant=None):
    '''
    Update an elastic pool.
    '''
    return call_az("az sql elastic-pool update", locals())


def list_dbs(name, resource_group, server):
    return call_az("az sql elastic-pool list-dbs", locals())


def list_editions(location, available=None, dtu=None, show_details=None, tier=None, vcores=None):
    '''
    List elastic pool editions available for the active subscription.
    '''
    return call_az("az sql elastic-pool list-editions", locals())




from .... pyaz_utils import call_az

def list(database_rid, instance_id, location):
    '''
    List all the versions of all the mongodb collections that were created / modified / deleted in the given database and restorable account.
    '''
    return call_az("az cosmosdb mongodb restorable-collection list", locals())




from ... pyaz_utils import call_az

def list(name, resource_group=None):
    '''
    List all environment of the static app including production.
    '''
    return call_az("az staticwebapp environment list", locals())


def show(name, environment_name=None, resource_group=None):
    '''
    Show information about the production environment or the specified environment.
    '''
    return call_az("az staticwebapp environment show", locals())


def functions(name, environment_name=None, resource_group=None):
    '''
    Show information about functions.
    '''
    return call_az("az staticwebapp environment functions", locals())


def delete(name, environment_name=None, resource_group=None, yes=None):
    '''
    Delete the static app production environment or the specified environment.
    '''
    return call_az("az staticwebapp environment delete", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    List all triggered webjobs hosted on a web app.
    '''
    return call_az("az webapp webjob triggered list", locals())


def remove(name, resource_group, webjob_name, slot=None):
    '''
    Delete a specific triggered webjob hosted on a web app.
    '''
    return call_az("az webapp webjob triggered remove", locals())


def run(name, resource_group, webjob_name, slot=None):
    '''
    Run a specific triggered webjob hosted on a web app.
    '''
    return call_az("az webapp webjob triggered run", locals())


def log(name, resource_group, webjob_name, slot=None):
    '''
    Get history of a specific triggered webjob hosted on a web app.
    '''
    return call_az("az webapp webjob triggered log", locals())




from .... pyaz_utils import call_az

def list(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Lists deployments for a resource policy remediation.
    '''
    return call_az("az policy remediation deployment list", locals())




from ... pyaz_utils import call_az
from . import contact, issuer, pending


def create(name, policy, vault_name, disabled=None, tags=None, validity=None):
    '''
    Create a Key Vault certificate.
    '''
    return call_az("az keyvault certificate create", locals())


def list(id=None, include_pending=None, maxresults=None, vault_name=None):
    return call_az("az keyvault certificate list", locals())


def list_versions(id=None, maxresults=None, name=None, vault_name=None):
    return call_az("az keyvault certificate list-versions", locals())


def list_deleted(vault_name, id=None, include_pending=None, maxresults=None):
    return call_az("az keyvault certificate list-deleted", locals())


def show(id=None, name=None, vault_name=None, version=None):
    return call_az("az keyvault certificate show", locals())


def show_deleted(id=None, name=None, vault_name=None):
    return call_az("az keyvault certificate show-deleted", locals())


def delete(id=None, name=None, vault_name=None):
    return call_az("az keyvault certificate delete", locals())


def purge(id=None, name=None, vault_name=None):
    return call_az("az keyvault certificate purge", locals())


def recover(id=None, name=None, vault_name=None):
    return call_az("az keyvault certificate recover", locals())


def set_attributes(certificate_attributes=None, enabled=None, id=None, name=None, policy=None, tags=None, vault_name=None, version=None):
    return call_az("az keyvault certificate set-attributes", locals())


def import_(file, name, vault_name, disabled=None, password=None, policy=None, tags=None):
    '''
    Import a certificate into KeyVault.
    '''
    return call_az("az keyvault certificate import", locals())


def download(file, encoding=None, id=None, name=None, vault_name=None, version=None):
    '''
    Download the public portion of a Key Vault certificate.
    '''
    return call_az("az keyvault certificate download", locals())


def get_default_policy(scaffold=None):
    '''
    Get the default policy for self-signed certificates.
    '''
    return call_az("az keyvault certificate get-default-policy", locals())


def backup(file, id=None, name=None, vault_name=None):
    return call_az("az keyvault certificate backup", locals())


def restore(file, vault_name):
    return call_az("az keyvault certificate restore", locals())




from .. pyaz_utils import call_az
from . import definition


def create(kind, managed_rg_id, name, resource_group, location=None, managedapp_definition_id=None, parameters=None, plan_name=None, plan_product=None, plan_publisher=None, plan_version=None, tags=None):
    '''
    Create a managed application.
    '''
    return call_az("az managedapp create", locals())


def delete(name, resource_group):
    '''
    Delete a managed application.
    '''
    return call_az("az managedapp delete", locals())


def show(name=None, resource_group=None):
    return call_az("az managedapp show", locals())


def list(resource_group=None):
    '''
    List managed applications.
    '''
    return call_az("az managedapp list", locals())




from .... pyaz_utils import call_az

def create(managed_instance, resource_group, display_name=None, object_id=None):
    '''
    Creates a new managed instance Active Directory administrator.
    '''
    return call_az("az sql mi ad-admin create", locals())


def list(managed_instance, resource_group):
    '''
    Returns a list of managed instance Active Directory Administrators.
    '''
    return call_az("az sql mi ad-admin list", locals())


def delete(managed_instance, resource_group):
    '''
    Deletes an existing managed instance Active Directory Administrator.
    '''
    return call_az("az sql mi ad-admin delete", locals())


def update(managed_instance, resource_group, display_name=None, object_id=None):
    '''
    Updates an existing managed instance Active Directory administrator.
    '''
    return call_az("az sql mi ad-admin update", locals())




from ... pyaz_utils import call_az

def show(name, resource_group, vault_name, backup_management_type=None, use_secondary_region=None):
    '''
    Show details of a container registered to a Recovery services vault.
    '''
    return call_az("az backup container show", locals())


def list(backup_management_type, resource_group, vault_name, use_secondary_region=None):
    '''
    List containers registered to a Recovery services vault.
    '''
    return call_az("az backup container list", locals())


def unregister(container_name, resource_group, vault_name, backup_management_type=None, yes=None):
    '''
    Unregister a Backup Container to make the underlying 'resource' be protected by another vault.
    '''
    return call_az("az backup container unregister", locals())


def re_register(container_name, resource_group, vault_name, workload_type, backup_management_type=None, yes=None):
    '''
    Reset the registration details for a given container.
    '''
    return call_az("az backup container re-register", locals())


def register(resource_group, resource_id, vault_name, workload_type, backup_management_type=None):
    '''
    Register a Resource to the given Recovery Services Vault.
    '''
    return call_az("az backup container register", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, server, end_ip_address=None, start_ip_address=None):
    '''
    Create a firewall rule.
    '''
    return call_az("az sql server firewall-rule create", locals())


def update(name, resource_group, server, end_ip_address=None, start_ip_address=None):
    '''
    Update a firewall rule.
    '''
    return call_az("az sql server firewall-rule update", locals())


def delete(name, resource_group, server):
    return call_az("az sql server firewall-rule delete", locals())


def show(name, resource_group, server):
    '''
    Shows the details for a firewall rule.
    '''
    return call_az("az sql server firewall-rule show", locals())


def list(resource_group, server):
    '''
    List a server's firewall rules.
    '''
    return call_az("az sql server firewall-rule list", locals())




from ... pyaz_utils import call_az

def create(categories, days, enabled, location, locations, name, service_bus_rule_id=None, storage_account_id=None, tags=None):
    '''
    Create a log profile.
    '''
    return call_az("az monitor log-profiles create", locals())


def delete(name):
    return call_az("az monitor log-profiles delete", locals())


def show(name):
    return call_az("az monitor log-profiles show", locals())


def list():
    return call_az("az monitor log-profiles list", locals())


def update(name, add=None, force_string=None, remove=None, set=None):
    '''
    Update a log profile.
    '''
    return call_az("az monitor log-profiles update", locals())




from ... pyaz_utils import call_az

def list(name, resource_group):
    '''
    List the access keys for a SignalR Service.
    '''
    return call_az("az signalr key list", locals())


def renew(key_type, name, resource_group):
    '''
    Regenerate the access key for a SignalR Service.
    '''
    return call_az("az signalr key renew", locals())




from .... pyaz_utils import call_az

def list(group):
    '''
    List group owners.
    '''
    return call_az("az ad group owner list", locals())


def add(group, owner_object_id):
    '''
    Add a group owner.
    '''
    return call_az("az ad group owner add", locals())


def remove(group, owner_object_id):
    '''
    Remove a group owner.
    '''
    return call_az("az ad group owner remove", locals())




from ..... pyaz_utils import call_az

def set(dh_group, ike_encryption, ike_integrity, ipsec_encryption, ipsec_integrity, name, pfs_group, resource_group, sa_lifetime, sa_max_size, no_wait=None):
    '''
    Set the VPN client connection ipsec policy per P2S client connection of the virtual network gateway.
    '''
    return call_az("az network vnet-gateway vpn-client ipsec-policy set", locals())


def show(name, resource_group):
    '''
    Get the VPN client connection ipsec policy per P2S client connection of the virtual network gateway.
    '''
    return call_az("az network vnet-gateway vpn-client ipsec-policy show", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vnet gateway vpn client ipsec policy is met.
    '''
    return call_az("az network vnet-gateway vpn-client ipsec-policy wait", locals())




from ... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Show CDN profile details.
    '''
    return call_az("az cdn profile show", locals())


def usage(name, resource_group):
    return call_az("az cdn profile usage", locals())


def delete(name, resource_group):
    '''
    Delete a CDN profile.
    '''
    return call_az("az cdn profile delete", locals())


def list(resource_group=None):
    '''
    List CDN profiles.
    '''
    return call_az("az cdn profile list", locals())


def create(name, resource_group, location=None, sku=None, tags=None):
    '''
    Create a new CDN profile.
    '''
    return call_az("az cdn profile create", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a CDN profile.
    '''
    return call_az("az cdn profile update", locals())




from ... pyaz_utils import call_az

def show(reserved_resource_type, subscription_id, location=None):
    '''
    Get catalog of available reservation.
    '''
    return call_az("az reservations catalog show", locals())




from ... pyaz_utils import call_az

def create(access_token, name, resource_group, add_disabled=None, is_validated=None):
    '''
    Create the Telegram Channel on a bot.
    '''
    return call_az("az bot telegram create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Telegram Channel on a bot
    '''
    return call_az("az bot telegram show", locals())


def delete(name, resource_group):
    '''
    Delete the Telegram Channel on a bot
    '''
    return call_az("az bot telegram delete", locals())




from ... pyaz_utils import call_az

def update(name, resource_group, username, no_wait=None, password=None, ssh_key_value=None):
    '''
    Update a user account.
    '''
    return call_az("az vm user update", locals())


def delete(name, resource_group, username, no_wait=None):
    '''
    Delete a user account from a VM.
    '''
    return call_az("az vm user delete", locals())


def reset_ssh(name, resource_group, no_wait=None):
    '''
    Reset the SSH configuration on a VM.
    '''
    return call_az("az vm user reset-ssh", locals())




from .... pyaz_utils import call_az
from . import throughput


def create(account_name, database_name, name, partition_key_path, resource_group, analytical_storage_ttl=None, conflict_resolution_policy=None, idx=None, max_throughput=None, partition_key_version=None, throughput=None, ttl=None, unique_key_policy=None):
    '''
    Create an SQL container under an Azure Cosmos DB SQL database.
    '''
    return call_az("az cosmosdb sql container create", locals())


def update(account_name, database_name, name, resource_group, analytical_storage_ttl=None, idx=None, ttl=None):
    '''
    Update an SQL container under an Azure Cosmos DB SQL database.
    '''
    return call_az("az cosmosdb sql container update", locals())


def exists(account_name, database_name, name, resource_group):
    return call_az("az cosmosdb sql container exists", locals())


def list(account_name, database_name, resource_group):
    '''
    List the SQL containers under an Azure Cosmos DB SQL database.
    '''
    return call_az("az cosmosdb sql container list", locals())


def show(account_name, database_name, name, resource_group):
    '''
    Show the details of a SQL container under an Azure Cosmos DB SQL database.
    '''
    return call_az("az cosmosdb sql container show", locals())


def delete(account_name, database_name, name, resource_group, yes=None):
    '''
    Delete the SQL container under an Azure Cosmos DB SQL database.
    '''
    return call_az("az cosmosdb sql container delete", locals())




from ..... pyaz_utils import call_az

def add(inbound_nat_rule, ip_config_name, nic_name, resource_group, lb_name=None):
    '''
    Add an inbound NAT rule to an IP configuration.
    '''
    return call_az("az network nic ip-config inbound-nat-rule add", locals())


def remove(inbound_nat_rule, ip_config_name, nic_name, resource_group, lb_name=None):
    '''
    Remove an inbound NAT rule of an IP configuration.
    '''
    return call_az("az network nic ip-config inbound-nat-rule remove", locals())




from .... pyaz_utils import call_az

def list(resource_group, service_name):
    '''
    Lists a collection of API Version Sets in the specified service instance.
    '''
    return call_az("az apim api versionset list", locals())


def show(resource_group, service_name, version_set_id):
    '''
    Gets the details of the Api Version Set specified by its identifier.
    '''
    return call_az("az apim api versionset show", locals())


def create(display_name, resource_group, service_name, versioning_scheme, description=None, if_match=None, version_header_name=None, version_query_name=None, version_set_id=None):
    '''
    Creates a Api Version Set.
    '''
    return call_az("az apim api versionset create", locals())


def update(resource_group, service_name, version_set_id, add=None, description=None, display_name=None, force_string=None, if_match=None, remove=None, set=None, version_header_name=None, version_query_name=None, versioning_scheme=None):
    '''
    Updates the details of the Api VersionSet specified by its identifier.
    '''
    return call_az("az apim api versionset update", locals())


def delete(resource_group, service_name, version_set_id, if_match=None):
    '''
    Deletes specific Api Version Set.
    '''
    return call_az("az apim api versionset delete", locals())




from .... pyaz_utils import call_az

def create(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, expiry_time=None, is_admin=None, json_file=None, name=None, password=None, ssh_public_key=None):
    '''
    Add a user account to a Batch compute node.
    '''
    return call_az("az batch node user create", locals())


def delete(node_id, pool_id, user_name, account_endpoint=None, account_key=None, account_name=None, yes=None):
    return call_az("az batch node user delete", locals())


def reset(node_id, pool_id, user_name, account_endpoint=None, account_key=None, account_name=None, expiry_time=None, json_file=None, password=None, ssh_public_key=None):
    '''
    Update the properties of a user account on a Batch compute node. Unspecified properties which can be updated are reset to their defaults.
    '''
    return call_az("az batch node user reset", locals())




from ... pyaz_utils import call_az

def create(definitions, name, definition_groups=None, description=None, display_name=None, management_group=None, metadata=None, params=None, subscription=None):
    '''
    Create a policy set definition.
    '''
    return call_az("az policy set-definition create", locals())


def delete(name, management_group=None, subscription=None):
    '''
    Delete a policy set definition.
    '''
    return call_az("az policy set-definition delete", locals())


def list(management_group=None, subscription=None):
    '''
    List policy set definitions.
    '''
    return call_az("az policy set-definition list", locals())


def show(name, management_group=None, subscription=None):
    '''
    Show a policy set definition.
    '''
    return call_az("az policy set-definition show", locals())


def update(name, definition_groups=None, definitions=None, description=None, display_name=None, management_group=None, metadata=None, params=None, subscription=None):
    '''
    Update a policy set definition.
    '''
    return call_az("az policy set-definition update", locals())




from .... pyaz_utils import call_az

def add(account_name, allowed_clients, cifs, nfsv3, nfsv41, pool_name, resource_group, rule_index, unix_read_only, unix_read_write, volume_name, add=None, force_string=None, remove=None, set=None):
    '''
    Add a new rule to the export policy for a volume.
    '''
    return call_az("az netappfiles volume export-policy add", locals())


def list(account_name, pool_name, resource_group, volume_name):
    '''
    List the export policy rules for a volume.
    '''
    return call_az("az netappfiles volume export-policy list", locals())


def remove(account_name, pool_name, resource_group, rule_index, volume_name, add=None, force_string=None, remove=None, set=None):
    '''
    Remove a rule from the export policy for a volume by rule index. The current rules can be obtained by performing the subgroup list command.
    '''
    return call_az("az netappfiles volume export-policy remove", locals())




from .... pyaz_utils import call_az

def delete(file_path, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, recursive=None, yes=None):
    return call_az("az batch node file delete", locals())


def download(destination, file_path, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, end_range=None, if_modified_since=None, if_unmodified_since=None, start_range=None):
    '''
    Download the content of the a node file.
    '''
    return call_az("az batch node file download", locals())


def show(file_path, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, if_modified_since=None, if_unmodified_since=None):
    return call_az("az batch node file show", locals())


def list(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, filter=None, recursive=None):
    return call_az("az batch node file list", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of a TXT record set.
    '''
    return call_az("az network private-dns record-set txt show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete a TXT record set and all associated records.
    '''
    return call_az("az network private-dns record-set txt delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List all TXT record sets in a zone.
    '''
    return call_az("az network private-dns record-set txt list", locals())


def create(name, resource_group, zone_name, metadata=None, record_type=None, ttl=None):
    '''
    Create an empty TXT record set.
    '''
    return call_az("az network private-dns record-set txt create", locals())


def add_record(record_set_name, resource_group, value, zone_name):
    '''
    Add a TXT record.
    '''
    return call_az("az network private-dns record-set txt add-record", locals())


def remove_record(record_set_name, resource_group, value, zone_name, keep_empty_record_set=None):
    '''
    Remove a TXT record from its record set.
    '''
    return call_az("az network private-dns record-set txt remove-record", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, metadata=None, record_type=None, remove=None, set=None):
    '''
    Update a TXT record set.
    '''
    return call_az("az network private-dns record-set txt update", locals())




from ... pyaz_utils import call_az

def list(resource_group, solution_name):
    '''
    List all IoT security Analytics metrics.
    '''
    return call_az("az security iot-analytics list", locals())


def show(resource_group, solution_name):
    '''
    Shows IoT Security Analytics metrics.
    '''
    return call_az("az security iot-analytics show", locals())




from .... pyaz_utils import call_az

def create(name, properties, resource_group, migration_name=None):
    '''
    Create a new migration workflow for a flexible server.
    '''
    return call_az("az postgres flexible-server migration create", locals())


def show(migration_name, name, resource_group, level=None):
    '''
    Get the details of a specific migration.
    '''
    return call_az("az postgres flexible-server migration show", locals())


def list(name, resource_group, filter=None):
    '''
    List the migrations of a flexible server.
    '''
    return call_az("az postgres flexible-server migration list", locals())


def update(migration_name, name, resource_group, cutover=None, db_names=None, overwrite_dbs=None, setup_replication=None, start_data_migration=None):
    '''
    Update a specific migration.
    '''
    return call_az("az postgres flexible-server migration update", locals())


def delete(migration_name, name, resource_group, yes=None):
    '''
    Delete a specific migration.
    '''
    return call_az("az postgres flexible-server migration delete", locals())


def check_name_availability(migration_name, name, resource_group):
    '''
    Checks if the provided migration-name can be used.
    '''
    return call_az("az postgres flexible-server migration check-name-availability", locals())




from ... pyaz_utils import call_az
from . import image


def delete(name, resource_group, vmss_name, no_wait=None):
    '''
    Delete an extension from a VMSS.
    '''
    return call_az("az vmss extension delete", locals())


def show(name, resource_group, vmss_name):
    '''
    Show details on a VMSS extension.
    '''
    return call_az("az vmss extension show", locals())


def set(name, publisher, resource_group, vmss_name, enable_auto_upgrade=None, extension_instance_name=None, force_update=None, no_auto_upgrade_minor_version=None, no_wait=None, protected_settings=None, provision_after_extensions=None, settings=None, version=None):
    '''
    Add an extension to a VMSS or update an existing extension.
    '''
    return call_az("az vmss extension set", locals())


def list(resource_group, vmss_name):
    '''
    List extensions associated with a VMSS.
    '''
    return call_az("az vmss extension list", locals())


def upgrade(name, resource_group, no_wait=None):
    '''
    Upgrade all extensions for all VMSS instances to the latest version.
    '''
    return call_az("az vmss extension upgrade", locals())




from .... pyaz_utils import call_az

def set(name, resource_group, server_name, value=None):
    '''
    Update the configuration of a server.
    '''
    return call_az("az mariadb server configuration set", locals())


def show(name, resource_group, server_name):
    '''
    Get the configuration for a server."
    '''
    return call_az("az mariadb server configuration show", locals())


def list(resource_group, server_name):
    '''
    List the configuration values for a server.
    '''
    return call_az("az mariadb server configuration list", locals())




from .... pyaz_utils import call_az

def list(kusto_pool_name, resource_group, workspace_name):
    '''
    Returns the list of databases of the given Kusto pool.
    '''
    return call_az("az synapse kusto database list", locals())


def show(database_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns a database.
    '''
    return call_az("az synapse kusto database show", locals())


def create(database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, read_write_database=None):
    '''
    Create a database.
    '''
    return call_az("az synapse kusto database create", locals())


def update(database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, read_write_database=None):
    '''
    Updates a database.
    '''
    return call_az("az synapse kusto database update", locals())


def delete(database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes the database with the given name.
    '''
    return call_az("az synapse kusto database delete", locals())


def wait(database_name, kusto_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto database is met.
    '''
    return call_az("az synapse kusto database wait", locals())




from ... pyaz_utils import call_az
from . import files


def restore_disks(container_name, item_name, resource_group, rp_name, storage_account, vault_name, disk_encryption_set_id=None, diskslist=None, mi_system_assigned=None, mi_user_assigned=None, rehydration_duration=None, rehydration_priority=None, restore_as_unmanaged_disks=None, restore_only_osdisk=None, restore_to_staging_storage_account=None, target_resource_group=None, target_zone=None, use_secondary_region=None):
    '''
    Restore disks of the backed VM from the specified recovery point.
    '''
    return call_az("az backup restore restore-disks", locals())


def restore_azurefileshare(container_name, item_name, resolve_conflict, resource_group, restore_mode, rp_name, vault_name, target_file_share=None, target_folder=None, target_storage_account=None):
    '''
    Restore backed up Azure file shares to the same file-share or another file-share in registered storage accounts.
    '''
    return call_az("az backup restore restore-azurefileshare", locals())


def restore_azurefiles(container_name, item_name, resolve_conflict, resource_group, restore_mode, rp_name, vault_name, source_file_path=None, source_file_type=None, target_file_share=None, target_folder=None, target_storage_account=None):
    '''
    Restore backed up Azure files within a file-share to the same file-share or another file-share in registered storage accounts.
    '''
    return call_az("az backup restore restore-azurefiles", locals())


def restore_azurewl(recovery_config, resource_group, vault_name, rehydration_duration=None, rehydration_priority=None, use_secondary_region=None):
    '''
    Restore backed up Azure Workloads in a Recovery services vault to another registered container or to the same container.
    '''
    return call_az("az backup restore restore-azurewl", locals())




from .... pyaz_utils import call_az

def add(name, subscription):
    '''
    Add a subscription to a management group.
    '''
    return call_az("az account management-group subscription add", locals())


def remove(name, subscription):
    '''
    Remove an existing subscription from a management group.
    '''
    return call_az("az account management-group subscription remove", locals())




from .... pyaz_utils import call_az
from . import metadata


def create(account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, metadata=None, permissions=None, sas_token=None, timeout=None, umask=None):
    '''
    Create a new file in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file create", locals())


def upload(source, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, metadata=None, overwrite=None, permissions=None, sas_token=None, timeout=None, umask=None):
    '''
    Upload a file to a file path in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file upload", locals())


def exists(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Check for the existence of a file in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file exists", locals())


def append(content, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Append content to a file in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file append", locals())


def download(account_key=None, account_name=None, auth_mode=None, connection_string=None, destination=None, overwrite=None, sas_token=None, timeout=None):
    '''
    Download a file from the specified path in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file download", locals())


def show(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Show properties of file in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file show", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, exclude_dir=None, marker=None, num_results=None, path=None, recursive=None, sas_token=None, show_next_marker=None, timeout=None):
    '''
    List files and directories in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file list", locals())


def move(new_path, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, sas_token=None):
    '''
    Move a file in ADLS Gen2 Account.
    '''
    return call_az("az storage fs file move", locals())


def delete(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None, yes=None):
    '''
    Delete a file in ADLS Gen2 file system.
    '''
    return call_az("az storage fs file delete", locals())




from .. pyaz_utils import call_az
from . import db, dw, elastic_pool, failover_group, instance_failover_group, instance_pool, midb, stg, virtual_cluster, vm


def list_usages(location):
    return call_az("az sql list-usages", locals())


def show_usage(location, usage):
    return call_az("az sql show-usage", locals())




from ... pyaz_utils import call_az

def set(app_version_ids, name, resource_group, app_config_overrides=None, order_applications=None):
    '''
    Set applications for VMSS.
    '''
    return call_az("az vmss application set", locals())


def list(name, resource_group):
    '''
    List applications for VMSS
    '''
    return call_az("az vmss application list", locals())




from ... pyaz_utils import call_az

def show(endpoint_name, profile_name, resource_group):
    '''
    Show details of an endpoint within the specified profile.
    '''
    return call_az("az afd endpoint show", locals())


def list(profile_name, resource_group):
    '''
    List all the endpoints within the specified profile.
    '''
    return call_az("az afd endpoint list", locals())


def purge(content_paths, endpoint_name, profile_name, resource_group, domains=None, no_wait=None):
    '''
    Removes cached contents from Azure Front Door.
    '''
    return call_az("az afd endpoint purge", locals())


def delete(endpoint_name, profile_name, resource_group, yes=None):
    '''
    Delete an endpoint within the specified profile.
    '''
    return call_az("az afd endpoint delete", locals())


def update(endpoint_name, profile_name, resource_group, enabled_state=None, origin_response_timeout_seconds=None, tags=None):
    '''
    Update an endpoint within the specified profile.
    '''
    return call_az("az afd endpoint update", locals())


def create(enabled_state, endpoint_name, origin_response_timeout_seconds, profile_name, resource_group, tags=None):
    '''
    Creates an endpoint within the specified profile.
    '''
    return call_az("az afd endpoint create", locals())




from .. pyaz_utils import call_az

def list(resource_group=None):
    '''
    List all deployment scripts.
    '''
    return call_az("az deployment-scripts list", locals())


def show(name, resource_group):
    '''
    Retrieve a deployment script.
    '''
    return call_az("az deployment-scripts show", locals())


def show_log(name, resource_group):
    '''
    Show deployment script logs.
    '''
    return call_az("az deployment-scripts show-log", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a deployment script.
    '''
    return call_az("az deployment-scripts delete", locals())




from .... pyaz_utils import call_az

def list(vault_name):
    return call_az("az keyvault certificate contact list", locals())


def add(email, vault_name, name=None, phone=None):
    return call_az("az keyvault certificate contact add", locals())


def delete(email, vault_name):
    return call_az("az keyvault certificate contact delete", locals())




from .... pyaz_utils import call_az

def add(account_name, action=None, ip_address=None, resource_group=None, resource_id=None, subnet=None, tenant_id=None, vnet_name=None):
    '''
    Add a network rule.
    '''
    return call_az("az storage account network-rule add", locals())


def list(account_name, resource_group=None):
    '''
    List network rules.
    '''
    return call_az("az storage account network-rule list", locals())


def remove(account_name, ip_address=None, resource_group=None, resource_id=None, subnet=None, tenant_id=None, vnet_name=None):
    '''
    Remove a network rule.
    '''
    return call_az("az storage account network-rule remove", locals())




from ... pyaz_utils import call_az

def list(name, resource_group):
    '''
    Get all Creator instances for an Azure Maps Account.
    '''
    return call_az("az maps creator list", locals())


def show(creator_name, name, resource_group):
    '''
    Get a Maps Creator resource.
    '''
    return call_az("az maps creator show", locals())


def create(creator_name, name, resource_group, storage_units, location=None, tags=None):
    '''
    Create a Maps Creator resource. Creator resource will manage Azure resources required to populate a custom set of mapping data. It requires an account to exist before it can be created.
    '''
    return call_az("az maps creator create", locals())


def update(creator_name, name, resource_group, storage_units=None, tags=None):
    '''
    Updates the Maps Creator resource. Only a subset of the parameters may be updated after creation, such as Tags.
    '''
    return call_az("az maps creator update", locals())


def delete(creator_name, name, resource_group, yes=None):
    '''
    Delete a Maps Creator resource.
    '''
    return call_az("az maps creator delete", locals())




from ... pyaz_utils import call_az
from . import ad, backup, backup_policy


def show(name, resource_group):
    '''
    Get the specified ANF account.
    '''
    return call_az("az netappfiles account show", locals())


def delete(name, resource_group):
    '''
    Delete the specified ANF account.
    '''
    return call_az("az netappfiles account delete", locals())


def list(resource_group=None):
    '''
    List ANF accounts by subscription or by resource group name.
    '''
    return call_az("az netappfiles account list", locals())


def create(location, name, resource_group, encryption=None, tags=None):
    '''
    Create a new Azure NetApp Files (ANF) account. Note that active directories are added using the subgroup commands.
    '''
    return call_az("az netappfiles account create", locals())


def update(name, resource_group, add=None, encryption=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Set/modify the tags for a specified ANF account.
    '''
    return call_az("az netappfiles account update", locals())




from ... pyaz_utils import call_az

def list(custom_role_only=None, name=None, resource_group=None, scope=None):
    '''
    List role definitions.
    '''
    return call_az("az role definition list", locals())


def delete(name, custom_role_only=None, resource_group=None, scope=None):
    '''
    Delete a role definition.
    '''
    return call_az("az role definition delete", locals())


def create(role_definition):
    '''
    Create a custom role definition.
    '''
    return call_az("az role definition create", locals())


def update(role_definition):
    '''
    Update a role definition.
    '''
    return call_az("az role definition update", locals())




from ... pyaz_utils import call_az

def create(account_name, name, resource_group, cbcs_clear_tracks=None, cbcs_default_key_label=None, cbcs_default_key_policy_name=None, cbcs_fair_play_allow_persistent_license=None, cbcs_fair_play_template=None, cbcs_key_to_track_mappings=None, cbcs_play_ready_attributes=None, cbcs_play_ready_template=None, cbcs_protocols=None, cbcs_widevine_template=None, cenc_clear_tracks=None, cenc_default_key_label=None, cenc_default_key_policy_name=None, cenc_disable_play_ready=None, cenc_disable_widevine=None, cenc_key_to_track_mappings=None, cenc_play_ready_attributes=None, cenc_play_ready_template=None, cenc_protocols=None, cenc_widevine_template=None, default_content_key_policy_name=None, envelope_clear_tracks=None, envelope_default_key_label=None, envelope_default_key_policy_name=None, envelope_key_to_track_mappings=None, envelope_protocols=None, envelope_template=None, no_encryption_protocols=None):
    '''
    Create a streaming policy.
    '''
    return call_az("az ams streaming-policy create", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the streaming policies within an Azure Media Services account.
    '''
    return call_az("az ams streaming-policy list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a streaming policy.
    '''
    return call_az("az ams streaming-policy show", locals())


def delete(account_name, name, resource_group):
    return call_az("az ams streaming-policy delete", locals())




from ... pyaz_utils import call_az
from . import throughput


def create(account_name, name, resource_group, max_throughput=None, throughput=None):
    '''
    Create an Table under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb table create", locals())


def exists(account_name, name, resource_group):
    return call_az("az cosmosdb table exists", locals())


def list(account_name, resource_group):
    '''
    List the Tables under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb table list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a Table under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb table show", locals())


def delete(account_name, name, resource_group, yes=None):
    '''
    Delete the Table under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb table delete", locals())




from ... pyaz_utils import call_az

def show(endpoint_name, profile_name, resource_group, route_name):
    '''
    Show route details.
    '''
    return call_az("az afd route show", locals())


def list(endpoint_name, profile_name, resource_group):
    '''
    List all the routes within the specified endpoint.
    '''
    return call_az("az afd route list", locals())


def create(endpoint_name, forwarding_protocol, https_redirect, origin_group, profile_name, resource_group, route_name, supported_protocols, content_types_to_compress=None, custom_domains=None, enable_compression=None, link_to_default_domain=None, origin_path=None, patterns_to_match=None, query_string_caching_behavior=None, rule_sets=None):
    '''
    Creates a new route within the specified endpoint.
    '''
    return call_az("az afd route create", locals())


def update(endpoint_name, profile_name, resource_group, route_name, content_types_to_compress=None, custom_domains=None, enable_compression=None, forwarding_protocol=None, https_redirect=None, link_to_default_domain=None, origin_group=None, origin_path=None, patterns_to_match=None, query_string_caching_behavior=None, rule_sets=None, supported_protocols=None):
    '''
    Update an existing route within the specified endpoint.
    '''
    return call_az("az afd route update", locals())


def delete(endpoint_name, profile_name, resource_group, route_name, yes=None):
    '''
    Delete an existing route within the specified endpoint.
    '''
    return call_az("az afd route delete", locals())




from ... pyaz_utils import call_az
from . import container, github_actions, slot, source, user


def list_publishing_profiles(name, resource_group, slot=None, xml=None):
    '''
    Get the details for available web app deployment profiles.
    '''
    return call_az("az webapp deployment list-publishing-profiles", locals())


def list_publishing_credentials(name, resource_group, slot=None):
    '''
    Get the details for available web app publishing credentials
    '''
    return call_az("az webapp deployment list-publishing-credentials", locals())




from ... pyaz_utils import call_az

def list():
    '''
    Adaptive Application Controls - List
    '''
    return call_az("az security adaptive-application-controls list", locals())


def show(group_name):
    '''
    Adaptive Application Controls - Get
    '''
    return call_az("az security adaptive-application-controls show", locals())




from .... pyaz_utils import call_az
from . import admin


def update(issuer_name, vault_name, account_id=None, enabled=None, organization_id=None, password=None, provider_name=None):
    return call_az("az keyvault certificate issuer update", locals())


def list(vault_name, maxresults=None):
    return call_az("az keyvault certificate issuer list", locals())


def create(issuer_name, provider_name, vault_name, account_id=None, disabled=None, organization_id=None, password=None):
    return call_az("az keyvault certificate issuer create", locals())


def show(issuer_name, vault_name):
    return call_az("az keyvault certificate issuer show", locals())


def delete(issuer_name, vault_name):
    return call_az("az keyvault certificate issuer delete", locals())




from ..... pyaz_utils import call_az

def show(name, profile_name, resource_group):
    '''
    show delivery rules asscociate with the endpoint.
    '''
    return call_az("az cdn endpoint rule condition show", locals())


def add(match_variable, name, operator, profile_name, resource_group, rule_name, match_values=None, negate_condition=None, selector=None, transform=None):
    '''
    Add a condition to a delivery rule.
    '''
    return call_az("az cdn endpoint rule condition add", locals())


def remove(index, name, profile_name, resource_group, rule_name):
    '''
    Remove a condition from a delivery rule.
    '''
    return call_az("az cdn endpoint rule condition remove", locals())




from ... pyaz_utils import call_az

def list(name, resource_group=None):
    '''
    List access keys of an App Configuration.
    '''
    return call_az("az appconfig credential list", locals())


def regenerate(id, name, resource_group=None):
    '''
    Regenerate an access key for an App Configuration.
    '''
    return call_az("az appconfig credential regenerate", locals())




from ... pyaz_utils import call_az
from . import authorization_rule


def create(name, namespace_name, resource_group, requires_client_authorization=None, user_metadata=None):
    '''
    Create the Relay Service Hybrid Connection
    '''
    return call_az("az relay hyco create", locals())


def show(name, namespace_name, resource_group):
    '''
    Shows the Relay Service Hybrid Connection Details
    '''
    return call_az("az relay hyco show", locals())


def list(namespace_name, resource_group):
    '''
    List the Hybrid Connection by Relay Service Namespace
    '''
    return call_az("az relay hyco list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Relay Service Hybrid Connection
    '''
    return call_az("az relay hyco delete", locals())


def update(name, namespace_name, resource_group, add=None, force_string=None, remove=None, requires_client_authorization=None, set=None, status=None, user_metadata=None):
    '''
    Updates the Relay Service Hybrid Connection
    '''
    return call_az("az relay hyco update", locals())




from .... pyaz_utils import call_az

def list(database_rid, instance_id, location, end_time=None, start_time=None):
    '''
    List all the versions of all the sql containers that were created / modified / deleted in the given database and restorable account.
    '''
    return call_az("az cosmosdb sql restorable-container list", locals())




from .... pyaz_utils import call_az

def approve(description=None, id=None, name=None, resource_group=None, server_name=None):
    '''
    Approve the specified private endpoint connection associated with a PostgreSQL server.
    '''
    return call_az("az postgres server private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, resource_group=None, server_name=None):
    '''
    Reject the specified private endpoint connection associated with a PostgreSQL server.
    '''
    return call_az("az postgres server private-endpoint-connection reject", locals())


def delete(id=None, name=None, resource_group=None, server_name=None):
    '''
    Delete the specified private endpoint connection associated with a PostgreSQL server.
    '''
    return call_az("az postgres server private-endpoint-connection delete", locals())


def show(id=None, name=None, resource_group=None, server_name=None):
    '''
    Show details of a private endpoint connection associated with a PostgreSQL server.
    '''
    return call_az("az postgres server private-endpoint-connection show", locals())




from ... pyaz_utils import call_az

def list(resource_group, service_name):
    return call_az("az search query-key list", locals())


def create(name, resource_group, service_name):
    return call_az("az search query-key create", locals())


def delete(key_value, resource_group, service_name):
    return call_az("az search query-key delete", locals())




from ... pyaz_utils import call_az

def enable(name, resource_group, workspace_id, no_wait=None):
    '''
    Enable Log Analytics monitoring in an ARO 3.11 cluster.
    '''
    return call_az("az openshift monitor enable", locals())


def disable(name, resource_group, no_wait=None):
    '''
    Disable Log Analytics monitoring in an ARO 3.11 cluster.
    '''
    return call_az("az openshift monitor disable", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, workspace_name, description=None, if_match=None, no_wait=None):
    '''
    Create an self-hosted integration runtime.
    '''
    return call_az("az synapse integration-runtime self-hosted create", locals())




from ... pyaz_utils import call_az

def list(resource_group, vault_name, backup_management_type=None, end_date=None, operation=None, start_date=None, status=None, use_secondary_region=None):
    '''
    List all backup jobs of a Recovery Services vault.
    '''
    return call_az("az backup job list", locals())


def show(name, resource_group, vault_name, use_secondary_region=None):
    '''
    Show details of a particular job.
    '''
    return call_az("az backup job show", locals())


def stop(name, resource_group, vault_name, use_secondary_region=None):
    '''
    Suspend or terminate a currently running job.
    '''
    return call_az("az backup job stop", locals())


def wait(name, resource_group, vault_name, timeout=None, use_secondary_region=None):
    '''
    Wait until either the job completes or the specified timeout value is reached.
    '''
    return call_az("az backup job wait", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, add_disabled=None, disablev1=None, disablev3=None, enable_enhanced_auth=None, trusted_origins=None):
    '''
    Create the DirectLine Channel on a bot with only v3 protocol enabled.
    '''
    return call_az("az bot directline create", locals())


def update(name, resource_group, add_disabled=None, disablev1=None, disablev3=None, enable_enhanced_auth=None, trusted_origins=None):
    '''
    Update the DirectLine Channel on a bot with only v3 protocol enabled.
    '''
    return call_az("az bot directline update", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Directline Channel on a bot
    '''
    return call_az("az bot directline show", locals())


def delete(name, resource_group):
    '''
    Delete the Directline Channel on a bot
    '''
    return call_az("az bot directline delete", locals())




from ... pyaz_utils import call_az

def add(name, resource_group, subnet, vnet, skip_delegation_check=None, slot=None):
    '''
    Add a regional virtual network integration to a functionapp
    '''
    return call_az("az functionapp vnet-integration add", locals())


def list(name, resource_group, slot=None):
    '''
    list the virtual network integrations on a functionapp
    '''
    return call_az("az functionapp vnet-integration list", locals())


def remove(name, resource_group, slot=None):
    '''
    remove a regional virtual network integration from functionapp
    '''
    return call_az("az functionapp vnet-integration remove", locals())




from ... pyaz_utils import call_az

def list(account_name, customer_name=None, invoice_section_name=None, profile_name=None):
    '''
    List the subscriptions for a billing account. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.
    '''
    return call_az("az billing subscription list", locals())


def show(account_name):
    '''
    Get a subscription by its ID. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement and Microsoft Partner Agreement.
    '''
    return call_az("az billing subscription show", locals())


def update(account_name, cost_center=None, sku_id=None, subscription_billing_status=None):
    '''
    Update the properties of a billing subscription. Currently, cost center can be updated. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing subscription update", locals())


def move(account_name, destination_invoice_section_id, no_wait=None):
    '''
    Moves a subscription's charges to a new invoice section. The new invoice section must belong to the same billing profile as the existing invoice section. This operation is supported for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing subscription move", locals())


def validate_move(account_name, destination_invoice_section_id):
    '''
    Validate if a subscription's charges can be moved to a new invoice section. This operation is supported for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing subscription validate-move", locals())


def wait(account_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing subscription is met.
    '''
    return call_az("az billing subscription wait", locals())




from ... pyaz_utils import call_az

def create(account_name, ips, name, resource_group, streaming_protocol, access_token=None, alternative_media_id=None, auto_start=None, client_access_policy=None, cross_domain_policy=None, description=None, encoding_type=None, hostname_prefix=None, key_frame_interval=None, key_frame_interval_duration=None, no_wait=None, preset_name=None, preview_ips=None, preview_locator=None, stream_options=None, streaming_policy_name=None, stretch_mode=None, tags=None, transcription_lang=None, use_static_hostname=None):
    '''
    Create a live event.
    '''
    return call_az("az ams live-event create", locals())


def start(account_name, name, resource_group, no_wait=None):
    '''
    Start a live event.
    '''
    return call_az("az ams live-event start", locals())


def standby(account_name, name, resource_group, no_wait=None):
    '''
    Allocate a live event to be started later.
    '''
    return call_az("az ams live-event standby", locals())


def stop(account_name, name, resource_group, no_wait=None, remove_outputs_on_stop=None):
    '''
    Stop a live event.
    '''
    return call_az("az ams live-event stop", locals())


def reset(account_name, name, resource_group, no_wait=None):
    '''
    Reset a live event.
    '''
    return call_az("az ams live-event reset", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a live event.
    '''
    return call_az("az ams live-event show", locals())


def delete(account_name, name, resource_group):
    '''
    Delete a live event.
    '''
    return call_az("az ams live-event delete", locals())


def list(account_name, resource_group):
    '''
    List all the live events of an Azure Media Services account.
    '''
    return call_az("az ams live-event list", locals())


def update(account_name, name, resource_group, add=None, client_access_policy=None, cross_domain_policy=None, description=None, force_string=None, ips=None, key_frame_interval_duration=None, preview_ips=None, remove=None, set=None, tags=None):
    '''
    Update the details of a live event.
    '''
    return call_az("az ams live-event update", locals())


def wait(account_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the live event is met.
    '''
    return call_az("az ams live-event wait", locals())




from ... pyaz_utils import call_az

def list(account_name, resource_group):
    '''
    List the private link resources supported for Azure Cosmos DB.
    '''
    return call_az("az cosmosdb private-link-resource list", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List rules.
    '''
    return call_az("az network application-gateway rule list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a rule.
    '''
    return call_az("az network application-gateway rule show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a rule.
    '''
    return call_az("az network application-gateway rule delete", locals())


def create(gateway_name, name, resource_group, address_pool=None, http_listener=None, http_settings=None, no_wait=None, priority=None, redirect_config=None, rewrite_rule_set=None, rule_type=None, url_path_map=None):
    '''
    Create a rule.
    '''
    return call_az("az network application-gateway rule create", locals())


def update(gateway_name, name, resource_group, add=None, address_pool=None, force_string=None, http_listener=None, http_settings=None, no_wait=None, priority=None, redirect_config=None, remove=None, rewrite_rule_set=None, rule_type=None, set=None, url_path_map=None):
    '''
    Update a rule.
    '''
    return call_az("az network application-gateway rule update", locals())




from ..... pyaz_utils import call_az

def list(alias, name, namespace_name, resource_group):
    '''
    List the keys and connection strings of Authorization Rule for the Service Bus Namespace
    '''
    return call_az("az servicebus georecovery-alias authorization-rule keys list", locals())




from ... pyaz_utils import call_az

def list(apply=None, filter=None, from_=None, management_group=None, namespace=None, order_by=None, parent=None, policy_assignment=None, policy_definition=None, policy_set_definition=None, resource=None, resource_group=None, resource_type=None, select=None, to=None, top=None):
    '''
    List policy events.
    '''
    return call_az("az policy event list", locals())




from .... pyaz_utils import call_az

def show(connection_name, resource_group):
    '''
    Retrieve a VPN connection shared key.
    '''
    return call_az("az network vpn-connection shared-key show", locals())


def reset(connection_name, key_length, resource_group=None):
    '''
    Reset a VPN connection shared key.
    '''
    return call_az("az network vpn-connection shared-key reset", locals())


def update(connection_name, resource_group, value, add=None, force_string=None, remove=None, set=None):
    '''
    Update a VPN connection shared key.
    '''
    return call_az("az network vpn-connection shared-key update", locals())




from ... pyaz_utils import call_az

def list(all=None, apply=None, expand=None, filter=None, from_=None, management_group=None, namespace=None, order_by=None, parent=None, policy_assignment=None, policy_definition=None, policy_set_definition=None, resource=None, resource_group=None, resource_type=None, select=None, to=None, top=None):
    '''
    List policy compliance states.
    '''
    return call_az("az policy state list", locals())


def summarize(filter=None, from_=None, management_group=None, namespace=None, parent=None, policy_assignment=None, policy_definition=None, policy_set_definition=None, resource=None, resource_group=None, resource_type=None, to=None, top=None):
    '''
    Summarize policy compliance states.
    '''
    return call_az("az policy state summarize", locals())


def trigger_scan(no_wait=None, resource_group=None):
    '''
    Trigger a policy compliance evaluation for a scope.
    '''
    return call_az("az policy state trigger-scan", locals())




from .... pyaz_utils import call_az
from . import rule


def create(name, namespace_name, resource_group, topic_name, auto_delete_on_idle=None, dead_letter_on_filter_exceptions=None, default_message_time_to_live=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_session=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, status=None):
    '''
    Create the ServiceBus Subscription
    '''
    return call_az("az servicebus topic subscription create", locals())


def show(name, namespace_name, resource_group, topic_name):
    '''
    Shows Service Bus Subscription Details
    '''
    return call_az("az servicebus topic subscription show", locals())


def list(namespace_name, resource_group, topic_name, skip=None, top=None):
    '''
    List the Subscription by Service Bus Topic
    '''
    return call_az("az servicebus topic subscription list", locals())


def delete(name, namespace_name, resource_group, topic_name):
    '''
    Deletes the Service Bus Subscription
    '''
    return call_az("az servicebus topic subscription delete", locals())


def update(name, namespace_name, resource_group, topic_name, add=None, auto_delete_on_idle=None, dead_letter_on_filter_exceptions=None, default_message_time_to_live=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_session=None, force_string=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, remove=None, set=None, status=None):
    '''
    Updates the ServiceBus Subscription
    '''
    return call_az("az servicebus topic subscription update", locals())




from ... pyaz_utils import call_az

def list():
    return call_az("az billing enrollment-account list", locals())


def show(name):
    return call_az("az billing enrollment-account show", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, scope_name):
    '''
    Show a scoped resource of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope scoped-resource show", locals())


def list(resource_group, scope_name):
    '''
    List all scoped resource of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope scoped-resource list", locals())


def create(linked_resource, name, resource_group, scope_name):
    '''
    Create a scoped resource for a private link scope resource.
    '''
    return call_az("az monitor private-link-scope scoped-resource create", locals())


def delete(name, resource_group, scope_name, yes=None):
    '''
    Delete a scoped resource of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope scoped-resource delete", locals())




from .... pyaz_utils import call_az

def create(autoscale_name, count, name, resource_group, timezone, copy_rules=None, end=None, max_count=None, min_count=None, recurrence=None, start=None):
    '''
    Create a fixed or recurring autoscale profile.
    '''
    return call_az("az monitor autoscale profile create", locals())


def list(autoscale_name, resource_group):
    '''
    List autoscale profiles.
    '''
    return call_az("az monitor autoscale profile list", locals())


def show(autoscale_name, name, resource_group):
    '''
    Show details of an autoscale profile.
    '''
    return call_az("az monitor autoscale profile show", locals())


def delete(autoscale_name, name, resource_group):
    '''
    Delete an autoscale profile.
    '''
    return call_az("az monitor autoscale profile delete", locals())


def list_timezones(offset=None, search_query=None):
    '''
    Look up time zone information.
    '''
    return call_az("az monitor autoscale profile list-timezones", locals())




from .... pyaz_utils import call_az

def create(kid, resource_group, server):
    '''
    Creates a server key.
    '''
    return call_az("az sql server key create", locals())


def delete(kid, resource_group, server):
    '''
    Deletes a server key.
    '''
    return call_az("az sql server key delete", locals())


def show(kid, resource_group, server):
    '''
    Shows a server key.
    '''
    return call_az("az sql server key show", locals())


def list(resource_group, server):
    return call_az("az sql server key list", locals())




from ... pyaz_utils import call_az

def create(name, storage_account, access_tier=None, enabled_protocols=None, metadata=None, quota=None, resource_group=None, root_squash=None):
    '''
    Create a new Azure file share under the specified storage account.
    '''
    return call_az("az storage share-rm create", locals())


def delete(name, storage_account, include=None, resource_group=None, snapshot=None, yes=None):
    '''
    Delete the specified Azure file share or share snapshot.
    '''
    return call_az("az storage share-rm delete", locals())


def exists(name, storage_account, resource_group=None):
    '''
    Check for the existence of an Azure file share.
    '''
    return call_az("az storage share-rm exists", locals())


def list(storage_account, include_deleted=None, include_snapshot=None, resource_group=None):
    '''
    List the Azure file shares under the specified storage account.
    '''
    return call_az("az storage share-rm list", locals())


def show(name, storage_account, expand=None, resource_group=None, snapshot=None):
    '''
    Show the properties for a specified Azure file share or share snapshot.
    '''
    return call_az("az storage share-rm show", locals())


def update(name, storage_account, access_tier=None, add=None, force_string=None, metadata=None, quota=None, remove=None, resource_group=None, root_squash=None, set=None):
    '''
    Update the properties for an Azure file share.
    '''
    return call_az("az storage share-rm update", locals())


def stats(name, storage_account, resource_group=None):
    '''
    Get the usage bytes of the data stored on the share.
    '''
    return call_az("az storage share-rm stats", locals())


def restore(deleted_version, name, storage_account, resource_group=None, restored_name=None):
    '''
    Restore a file share within a valid retention days if share soft delete is enabled.
    '''
    return call_az("az storage share-rm restore", locals())


def snapshot(name, storage_account, access_tier=None, enabled_protocols=None, metadata=None, quota=None, resource_group=None, root_squash=None):
    '''
    Create a snapshot of an existing share under the specified account.
    '''
    return call_az("az storage share-rm snapshot", locals())




from ... pyaz_utils import call_az
from . import deployment


def tail(name, resource_group, provider=None, slot=None):
    '''
    Start live log tracing for a web app.
    '''
    return call_az("az webapp log tail", locals())


def download(name, resource_group, log_file=None, slot=None):
    '''
    Download a web app's log history as a zip file.
    '''
    return call_az("az webapp log download", locals())


def config(name, resource_group, application_logging=None, detailed_error_messages=None, docker_container_logging=None, failed_request_tracing=None, level=None, slot=None, web_server_logging=None):
    '''
    Configure logging for a web app.
    '''
    return call_az("az webapp log config", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a web app's logging configuration.
    '''
    return call_az("az webapp log show", locals())




from .... pyaz_utils import call_az

def show(resource_group, storage_account):
    '''
    Display Advanced Threat Protection settings for a storage account.
    '''
    return call_az("az security atp storage show", locals())


def update(is_enabled, resource_group, storage_account):
    '''
    Toggle status of Advanced Threat Protection for a storage account.
    '''
    return call_az("az security atp storage update", locals())




from .... pyaz_utils import call_az

def delete(name, nsg_name, resource_group):
    '''
    Delete a network security group rule.
    '''
    return call_az("az network nsg rule delete", locals())


def list(nsg_name, resource_group, include_default=None):
    '''
    List all rules in a network security group.
    '''
    return call_az("az network nsg rule list", locals())


def show(name, nsg_name, resource_group):
    '''
    Get the details of a network security group rule.
    '''
    return call_az("az network nsg rule show", locals())


def create(name, nsg_name, priority, resource_group, access=None, description=None, destination_address_prefixes=None, destination_asgs=None, destination_port_ranges=None, direction=None, protocol=None, source_address_prefixes=None, source_asgs=None, source_port_ranges=None):
    '''
    Create a network security group rule.
    '''
    return call_az("az network nsg rule create", locals())


def update(name, nsg_name, resource_group, access=None, add=None, description=None, destination_address_prefixes=None, destination_asgs=None, destination_port_ranges=None, direction=None, force_string=None, priority=None, protocol=None, remove=None, set=None, source_address_prefixes=None, source_asgs=None, source_port_ranges=None):
    '''
    Update a network security group rule.
    '''
    return call_az("az network nsg rule update", locals())




from .... pyaz_utils import call_az

def list(name):
    '''
    List deployment operations at tenant scope.
    '''
    return call_az("az deployment operation tenant list", locals())


def show(name, operation_ids):
    '''
    Show a deployment operation at tenant scope.
    '''
    return call_az("az deployment operation tenant show", locals())




from ... pyaz_utils import call_az

def create(contact_info, hostname, resource_group, accept_terms=None, auto_renew=None, dryrun=None, privacy=None, tags=None):
    '''
    Create and purchase a custom domain.
    '''
    return call_az("az appservice domain create", locals())


def show_terms(hostname):
    '''
    Show the legal terms for purchasing and creating a custom domain.
    '''
    return call_az("az appservice domain show-terms", locals())




from ..... pyaz_utils import call_az

def show(name, resource_group, workspace_name):
    '''
    Get a SQL pool's auditing policy.
    '''
    return call_az("az synapse sql pool audit-policy show", locals())


def update(name, resource_group, workspace_name, actions=None, add=None, blob_storage_target_state=None, enable_azure_monitor=None, event_hub=None, event_hub_authorization_rule_id=None, event_hub_target_state=None, force_string=None, log_analytics_target_state=None, log_analytics_workspace_resource_id=None, remove=None, retention_days=None, set=None, state=None, storage_account=None, storage_endpoint=None, storage_key=None, storage_subscription=None, use_secondary_key=None):
    '''
    Update a SQL pool's auditing policy.
    '''
    return call_az("az synapse sql pool audit-policy update", locals())




from .... pyaz_utils import call_az

def show(resource_group, server):
    '''
    Gets a server's secure connection policy.
    '''
    return call_az("az sql server conn-policy show", locals())


def update(connection_type, resource_group, server):
    '''
    Updates a server's secure connection policy.
    '''
    return call_az("az sql server conn-policy update", locals())




from ... pyaz_utils import call_az

def create(name, storage_account, default_encryption_scope=None, deny_encryption_scope_override=None, enable_vlw=None, fail_on_exist=None, metadata=None, public_access=None, resource_group=None, root_squash=None):
    '''
    Create a new container under the specified storage account.
    '''
    return call_az("az storage container-rm create", locals())


def delete(name, storage_account, resource_group=None, yes=None):
    '''
    Delete the specified container under its account.
    '''
    return call_az("az storage container-rm delete", locals())


def update(name, storage_account, add=None, default_encryption_scope=None, deny_encryption_scope_override=None, force_string=None, metadata=None, public_access=None, remove=None, resource_group=None, root_squash=None, set=None):
    '''
    Update the properties for a container.
    '''
    return call_az("az storage container-rm update", locals())


def list(storage_account, include_deleted=None, resource_group=None):
    '''
    List all containers under the specified storage account.
    '''
    return call_az("az storage container-rm list", locals())


def exists(name, storage_account, resource_group=None):
    '''
    Check for the existence of a container.
    '''
    return call_az("az storage container-rm exists", locals())


def show(name, storage_account, resource_group=None):
    '''
    Show the properties for a specified container.
    '''
    return call_az("az storage container-rm show", locals())


def migrate_vlw(name, storage_account, no_wait=None, resource_group=None):
    '''
    Migrate a blob container from container level WORM to object level immutability enabled container.
    '''
    return call_az("az storage container-rm migrate-vlw", locals())




from ... pyaz_utils import call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a linked service.
    '''
    return call_az("az synapse linked-service create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist linked service.
    '''
    return call_az("az synapse linked-service set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist linked service.
    '''
    return call_az("az synapse linked-service update", locals())


def list(workspace_name):
    '''
    List linked services.
    '''
    return call_az("az synapse linked-service list", locals())


def show(name, workspace_name):
    '''
    Get a linked service.
    '''
    return call_az("az synapse linked-service show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a linked service.
    '''
    return call_az("az synapse linked-service delete", locals())




from .... pyaz_utils import call_az

def list(id):
    '''
    List application owners.
    '''
    return call_az("az ad app owner list", locals())


def add(id, owner_object_id):
    '''
    Add an application owner.
    '''
    return call_az("az ad app owner add", locals())


def remove(id, owner_object_id):
    '''
    Remove an application owner.
    '''
    return call_az("az ad app owner remove", locals())




from ..... pyaz_utils import call_az

def add(connection_monitor, location, name, address=None, address_exclude=None, address_include=None, coverage_level=None, dest_test_groups=None, filter_item=None, filter_type=None, resource_id=None, source_test_groups=None, type=None):
    '''
    Add an endpoint to a connection monitor
    '''
    return call_az("az network watcher connection-monitor endpoint add", locals())


def remove(connection_monitor, location, name, test_groups=None):
    '''
    Remove an endpoint from a connection monitor
    '''
    return call_az("az network watcher connection-monitor endpoint remove", locals())


def show(connection_monitor, location, name):
    '''
    Show an endpoint from a connection monitor
    '''
    return call_az("az network watcher connection-monitor endpoint show", locals())


def list(connection_monitor, location):
    '''
    List all endpoints form a connection monitor
    '''
    return call_az("az network watcher connection-monitor endpoint list", locals())




from ..... pyaz_utils import call_az

def create(name, value, operator=None):
    '''
    Build a metric alert rule dimension.
    '''
    return call_az("az monitor metrics alert dimension create", locals())




from .... pyaz_utils import call_az

def list(hub_name, resource_group=None):
    '''
    Lists all certificates contained within an Azure IoT Hub
    '''
    return call_az("az iot hub certificate list", locals())


def show(hub_name, name, resource_group=None):
    '''
    Shows information about a particular Azure IoT Hub certificate.
    '''
    return call_az("az iot hub certificate show", locals())


def create(hub_name, name, path, resource_group=None, verified=None):
    '''
    Create/upload an Azure IoT Hub certificate.
    '''
    return call_az("az iot hub certificate create", locals())


def delete(etag, hub_name, name, resource_group=None):
    '''
    Deletes an Azure IoT Hub certificate.
    '''
    return call_az("az iot hub certificate delete", locals())


def generate_verification_code(etag, hub_name, name, resource_group=None):
    '''
    Generates a verification code for an Azure IoT Hub certificate.
    '''
    return call_az("az iot hub certificate generate-verification-code", locals())


def verify(etag, hub_name, name, path, resource_group=None):
    '''
    Verifies an Azure IoT Hub certificate.
    '''
    return call_az("az iot hub certificate verify", locals())


def update(etag, hub_name, name, path, resource_group=None, verified=None):
    '''
    Update an Azure IoT Hub certificate.
    '''
    return call_az("az iot hub certificate update", locals())




from .... pyaz_utils import call_az

def add(dns, domain, name, password, resource_group, smb_server_name, username, ad_name=None, add=None, administrators=None, aes_encryption=None, allow_local_ldap_users=None, backup_operators=None, force_string=None, kdc_ip=None, ldap_over_tls=None, ldap_signing=None, organizational_unit=None, remove=None, security_operators=None, server_root_ca_cert=None, set=None, tags=None):
    '''
    Add an active directory to the account.
    '''
    return call_az("az netappfiles account ad add", locals())


def list(name, resource_group):
    '''
    List the active directories of an account.
    '''
    return call_az("az netappfiles account ad list", locals())


def remove(active_directory, name, resource_group):
    '''
    Remove an active directory from the account.
    '''
    return call_az("az netappfiles account ad remove", locals())




from ... pyaz_utils import call_az
from . import copy, metadata


def list(share_name, account_key=None, account_name=None, connection_string=None, exclude_dir=None, marker=None, num_results=None, path=None, sas_token=None, snapshot=None, timeout=None):
    '''
    List files and directories in a share.
    '''
    return call_az("az storage file list", locals())


def delete(path, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage file delete", locals())


def resize(path, share_name, size, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage file resize", locals())


def url(path, share_name, account_key=None, account_name=None, connection_string=None, protocol=None, sas_token=None):
    '''
    Create the url to access a file.
    '''
    return call_az("az storage file url", locals())


def generate_sas(path, share_name, account_key=None, account_name=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    return call_az("az storage file generate-sas", locals())


def show(path, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    return call_az("az storage file show", locals())


def update(path, share_name, account_key=None, account_name=None, clear_content_settings=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, sas_token=None, timeout=None):
    return call_az("az storage file update", locals())


def exists(path, share_name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Check for the existence of a file.
    '''
    return call_az("az storage file exists", locals())


def download(path, share_name, account_key=None, account_name=None, connection_string=None, dest=None, end_range=None, max_connections=None, no_progress=None, open_mode=None, sas_token=None, snapshot=None, start_range=None, timeout=None, validate_content=None):
    return call_az("az storage file download", locals())


def upload(share_name, source, account_key=None, account_name=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, max_connections=None, metadata=None, no_progress=None, path=None, sas_token=None, timeout=None, validate_content=None):
    '''
    Upload a file to a share that uses the SMB 3.0 protocol.
    '''
    return call_az("az storage file upload", locals())


def upload_batch(destination, source, account_key=None, account_name=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, destination_path=None, dryrun=None, max_connections=None, metadata=None, no_progress=None, pattern=None, sas_token=None, validate_content=None):
    '''
    Upload files from a local directory to an Azure Storage File Share in a batch operation.
    '''
    return call_az("az storage file upload-batch", locals())


def download_batch(destination, source, account_key=None, account_name=None, connection_string=None, dryrun=None, max_connections=None, no_progress=None, pattern=None, sas_token=None, snapshot=None, validate_content=None):
    '''
    Download files from an Azure Storage File Share to a local directory in a batch operation.
    '''
    return call_az("az storage file download-batch", locals())


def delete_batch(source, account_key=None, account_name=None, connection_string=None, dryrun=None, pattern=None, sas_token=None, timeout=None):
    '''
    Delete files from an Azure Storage File Share.
    '''
    return call_az("az storage file delete-batch", locals())




from .... pyaz_utils import call_az

def acquire(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, lease_duration=None, proposed_lease_id=None, sas_token=None, timeout=None):
    return call_az("az storage container lease acquire", locals())


def renew(container_name, lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, sas_token=None, timeout=None):
    return call_az("az storage container lease renew", locals())


def release(container_name, lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, sas_token=None, timeout=None):
    return call_az("az storage container lease release", locals())


def change(container_name, lease_id, proposed_lease_id, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, sas_token=None, timeout=None):
    return call_az("az storage container lease change", locals())


def break_(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, lease_break_period=None, sas_token=None, timeout=None):
    return call_az("az storage container lease break", locals())




from .. pyaz_utils import call_az

def list():
    '''
    List registered clouds.
    '''
    return call_az("az cloud list", locals())


def show(name=None):
    '''
    Get the details of a registered cloud.
    '''
    return call_az("az cloud show", locals())


def register(name, cloud_config=None, endpoint_active_directory=None, endpoint_active_directory_data_lake_resource_id=None, endpoint_active_directory_graph_resource_id=None, endpoint_active_directory_resource_id=None, endpoint_gallery=None, endpoint_management=None, endpoint_resource_manager=None, endpoint_sql_management=None, endpoint_vm_image_alias_doc=None, profile=None, suffix_acr_login_server_endpoint=None, suffix_azure_datalake_analytics_catalog_and_job_endpoint=None, suffix_azure_datalake_store_file_system_endpoint=None, suffix_keyvault_dns=None, suffix_sql_server_hostname=None, suffix_storage_endpoint=None):
    '''
    Register a cloud.
    '''
    return call_az("az cloud register", locals())


def unregister(name):
    '''
    Unregister a cloud.
    '''
    return call_az("az cloud unregister", locals())


def set(name, profile=None):
    '''
    Set the active cloud.
    '''
    return call_az("az cloud set", locals())


def update(cloud_config=None, endpoint_active_directory=None, endpoint_active_directory_data_lake_resource_id=None, endpoint_active_directory_graph_resource_id=None, endpoint_active_directory_resource_id=None, endpoint_gallery=None, endpoint_management=None, endpoint_resource_manager=None, endpoint_sql_management=None, endpoint_vm_image_alias_doc=None, name=None, profile=None, suffix_acr_login_server_endpoint=None, suffix_azure_datalake_analytics_catalog_and_job_endpoint=None, suffix_azure_datalake_store_file_system_endpoint=None, suffix_keyvault_dns=None, suffix_sql_server_hostname=None, suffix_storage_endpoint=None):
    '''
    Update the configuration of a cloud.
    '''
    return call_az("az cloud update", locals())


def list_profiles(name=None, show_all=None):
    '''
    List the supported profiles for a cloud.
    '''
    return call_az("az cloud list-profiles", locals())




from ... pyaz_utils import call_az

def list():
    '''
    Shows the Azure Security Center Home region location.
    '''
    return call_az("az security location list", locals())


def show(name):
    '''
    Shows the Azure Security Center Home region location.
    '''
    return call_az("az security location show", locals())

